@@ -16,8 +16,8 @@
 
 """Tests NotificationProcessor"""
 
-import mock
 import time
+from unittest import mock
 
 from monasca_notification import notification as m_notification
 from monasca_notification.plugins import email_notifier
